.. _quickstart:

Quickstart
==========

Eager to get started?  This page gives a good introduction to Choppy.  It
assumes you already have Choppy installed.  If you do not, head over to the
:ref:`installation` section.

RNA-Seq Example
---------------
